@@ -1,7 +1,7 @@
 /* Declarations of functions and data types used for MD4 sum
    library functions.
-   Copyright (C) 2000, 2001, 2003, 2005, 2008, 2009, 2010 Free Software
-   Foundation, Inc.
+   Copyright (C) 2000-2001, 2003, 2005, 2008-2012 Free Software Foundation,
+   Inc.
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
