@@ -1,5 +1,5 @@
 /* internal.h --- Internal header file for Shishi.
- * Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008, 2010  Simon Josefsson
+ * Copyright (C) 2002-2012 Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -78,7 +78,7 @@
 
 #include "xvasprintf.h"
 #include "base64.h"
-#include "getdate.h"
+#include "parse-datetime.h"
 #include "read-file.h"
 #include "timespec.h"
 #include "xalloc.h"
