@@ -1,5 +1,5 @@
 /* starttls.c --- Network I/O functions for Shishi over TLS.
- * Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008, 2010  Simon Josefsson
+ * Copyright (C) 2002-2012 Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -107,7 +107,8 @@ _shishi_sendrecv_tls1 (Shishi * handle,
       memcmp (extbuf, STARTTLS_SERVER_ACCEPT, STARTTLS_LEN) != 0)
     return SHISHI_RECVFROM_ERROR;
 
-  gnutls_transport_set_ptr (session, (gnutls_transport_ptr) sockfd);
+  gnutls_transport_set_ptr (session, (gnutls_transport_ptr)
+			    (unsigned long) sockfd);
 
   if (session_data_size > 0)
     gnutls_session_set_data (session, session_data, session_data_size);
@@ -230,9 +231,6 @@ _shishi_sendrecv_tls (Shishi * handle,
 		      const char *indata, size_t inlen,
 		      char **outdata, size_t * outlen)
 {
-  const int kx_prio[] = { GNUTLS_KX_RSA, GNUTLS_KX_DHE_DSS,
-    GNUTLS_KX_DHE_RSA, GNUTLS_KX_ANON_DH, 0
-  };
   gnutls_session session;
   gnutls_anon_client_credentials anoncred;
   gnutls_certificate_credentials x509cred;
@@ -265,10 +263,10 @@ _shishi_sendrecv_tls (Shishi * handle,
       return SHISHI_CRYPTO_ERROR;
     }
 
-  ret = gnutls_set_default_priority (session);
+  ret = gnutls_priority_set_direct (session, "NORMAL:+ANON-DH", NULL);
   if (ret != GNUTLS_E_SUCCESS)
     {
-      shishi_error_printf (handle, "TLS sdp failed (%d): %s",
+      shishi_error_printf (handle, "TLS psd failed (%d): %s",
 			   ret, gnutls_strerror (ret));
       return SHISHI_CRYPTO_ERROR;
     }
@@ -330,14 +328,6 @@ _shishi_sendrecv_tls (Shishi * handle,
       return SHISHI_CRYPTO_ERROR;
     }
 
-  ret = gnutls_kx_set_priority (session, kx_prio);
-  if (ret != GNUTLS_E_SUCCESS)
-    {
-      shishi_error_printf (handle, "TLS ksp failed (%d): %s",
-			   ret, gnutls_strerror (ret));
-      return SHISHI_CRYPTO_ERROR;
-    }
-
   /* Core part. */
   outerr = _shishi_sendrecv_tls1 (handle, sockfd, session, indata, inlen,
 				  outdata, outlen, handle->kdctimeout,
